@@ -3,6 +3,8 @@
 # set PS4 explicitly to be POSIX shell compatible for set -x
 export PS4=+
 
+mkdir m4 >/dev/null 2>&1
+
 if autoreconf -V >/dev/null 2>&1 ; then
     set -x
     autoreconf -i -f
@@ -15,7 +17,4 @@ else
     automake -ca -Wno-portability
 fi
 
-if [ -z "$NO_CONFIGURE" ]; then
-   ./configure "$@" 
-fi
 
